<?php

/**
 * @file
 * Widgets for taxonomy facets rendered as links.
 */

/**
 * Widget that renders taxonomy facets as a list of clickable links.
 */
class FacetapiTaxonomyLinks extends FacetapiWidgetLinks {

  /**
   * Recursive function that converts the render array into an array that can be
   * passed to theme_item_list().
   *
   * @param array $build
   *   The facet's render array.
   *
   * @return array
   *   The "items" parameter for theme_item_list().
   */
  function buildListItems($build) {

    // Start with the default items generated by FacetapiWidgetLinks::buildListItems();
    $items = parent::buildListItems($build);

    // Iterate through the build array and add a taxonomy term class to each
    // of the corresponding list items.
    $i = 0;
    foreach ($build as $tid => $item) {

      // Convert the term name to a valid CSS class.
      // (Uses code from D7+'s drupal_clean_css_identifier() function).
      $identifier = $item['#value'];
      $filter = array(' ' => '-', '_' => '-', '/' => '-', '[' => '-', ']' => '');
      $identifier = strtr($identifier, $filter);
      $identifier = preg_replace('/[^\x{002D}\x{0030}-\x{0039}\x{0041}-\x{005A}\x{005F}\x{0061}-\x{007A}\x{00A1}-\x{FFFF}]/u', '', $identifier);

      // Add the class to the item.
      $items[$i]['class'] .= ' term-' . $identifier;
      $i++;
    }

    // Return the new list of items.
    return $items;
  }
}

/**
 * Widget that renders taxonomy facets as a list of clickable checkboxes.
 */
class FacetapiTaxonomyCheckboxLinks extends FacetapiTaxonomyLinks {

  /**
   * Adds JavaScript settings.
   */
  public function init() {
    parent::init();
    $this->jsSettings['makeCheckboxes'] = 1;

    // Add Javascript.
    drupal_add_js(drupal_get_path('module', 'facetapi_taxonomy_links') . '/facetapi_taxonomy_links.js');
  }

  /**
   * Sets the base class for checkbox facet items.
   *
   * @return array
   *   An array of classes.
   */
  public function getItemClasses() {
    return array('facetapi-checkbox');
  }
}

